// ==UserScript==
// @id             iitc-plugin-highlight-imminent-decay@cathesaurus
// @name           IITC plugin: highlight portals with resonators about to decay
// @category       Highlighter
// @version        0.1.0.20131122.201127
// @namespace      https://github.com/jonatkins/ingress-intel-total-conversion
// @updateURL      none
// @downloadURL    none
// @description    [fdroid-2013-11-22-201127] Uses the fill color of the portals to show resonators due to decay within the next day. Red = portal will decay completely, orange = portal will drop all links, yellow = one or more resonators will decay completely.
// @include        https://www.ingress.com/intel*
// @include        http://www.ingress.com/intel*
// @match          https://www.ingress.com/intel*
// @match          http://www.ingress.com/intel*
// @grant          none
// ==/UserScript==


function wrapper(plugin_info) {
// ensure plugin framework is there, even if iitc is not yet loaded
if(typeof window.plugin !== 'function') window.plugin = function() {};

//PLUGIN AUTHORS: writing a plugin outside of the IITC build environment? if so, delete these lines!!
//(leaving them in place might break the 'About IITC' page or break update checks)
plugin_info.buildName = 'fdroid';
plugin_info.dateTimeVersion = '20131122.201127';
plugin_info.pluginId = 'portal-highlighter-imminent-decay';
//END PLUGIN AUTHORS NOTE



// PLUGIN START ////////////////////////////////////////////////////////

// use own namespace for plugin
window.plugin.portalHighlighterImminentDecay = function() {};

window.plugin.portalHighlighterImminentDecay.highlight = function(data) {
  var d = data.portal.options.details;
  if(getTeam(d) !== 0) {
    //Check the energy of every resonator.
    var resImminentDecayCount = 0;
    var resCount = 0;
    $.each(d.resonatorArray.resonators, function(ind, reso) {
      if(reso !== null) {
        var level = parseInt(reso.level);
        var maxResonatorEnergy = window.RESO_NRG[level];
        var currentResonatorEnergy = parseInt(reso.energyTotal);
        if((currentResonatorEnergy / maxResonatorEnergy) < 0.15) {
          resImminentDecayCount++;
        }
        resCount++;
      }
    });

    if(resImminentDecayCount > 0) {
      if(resImminentDecayCount === resCount) {
        var color = 'red';
      } else if((resCount - resImminentDecayCount) < 3) {
        color = 'orange';
      } else {
        color = 'yellow';
      }
      // Apply colour to portal.
      var params = {fillColor: color, fillOpacity: 1};
      data.portal.setStyle(params);
    }
  }
  window.COLOR_SELECTED_PORTAL = '#f0f';
}

var setup =  function() {
  window.addPortalHighlighter('Imminent Decay', window.plugin.portalHighlighterImminentDecay.highlight);
}

// PLUGIN END //////////////////////////////////////////////////////////


setup.info = plugin_info; //add the script info data to the function as a property
if(!window.bootPlugins) window.bootPlugins = [];
window.bootPlugins.push(setup);
// if IITC has already booted, immediately run the 'setup' function
if(window.iitcLoaded && typeof setup === 'function') setup();
} // wrapper end
// inject code into site context
var script = document.createElement('script');
var info = {};
if (typeof GM_info !== 'undefined' && GM_info && GM_info.script) info.script = { version: GM_info.script.version, name: GM_info.script.name, description: GM_info.script.description };
script.appendChild(document.createTextNode('('+ wrapper +')('+JSON.stringify(info)+');'));
(document.body || document.head || document.documentElement).appendChild(script);


