// ==UserScript==
// @id             iitc-plugin-show-less-portals@jonatkins
// @name           IITC plugin: Show less portals when zoomed out
// @category       Tweaks
// @version        0.1.4.20131122.201127
// @namespace      https://github.com/jonatkins/ingress-intel-total-conversion
// @updateURL      none
// @downloadURL    none
// @description    [fdroid-2013-11-22-201127] Decrease the portal detail level used when zoomed out. This can speed up map loading, decrease the amount of data used, and solve excessive request issues. Only applies when zoomed out to show no closer than L3 portals. May stop display of the smaller links/fields.
// @include        https://www.ingress.com/intel*
// @include        http://www.ingress.com/intel*
// @match          https://www.ingress.com/intel*
// @match          http://www.ingress.com/intel*
// @grant          none
// ==/UserScript==


function wrapper(plugin_info) {
// ensure plugin framework is there, even if iitc is not yet loaded
if(typeof window.plugin !== 'function') window.plugin = function() {};

//PLUGIN AUTHORS: writing a plugin outside of the IITC build environment? if so, delete these lines!!
//(leaving them in place might break the 'About IITC' page or break update checks)
plugin_info.buildName = 'fdroid';
plugin_info.dateTimeVersion = '20131122.201127';
plugin_info.pluginId = 'show-less-portals-zoomed-out';
//END PLUGIN AUTHORS NOTE



// PLUGIN START ////////////////////////////////////////////////////////


// use own namespace for plugin
window.plugin.showLessPortals = function() {};

window.plugin.showLessPortals.setup  = function() {

  // save the original function - so we can chain to it for levels we don't modify
  var origGetPortalDataZoom = window.getPortalDataZoom;

  // replace the window.getPortalDataZoom function - modify behaviour when zoomed close

  window.getPortalDataZoom = function() {
    var mapZoom = map.getZoom();

    // the latest intel site update, as of 2013-10-16, requests a silly number of map tiles at the larger zoom levels
    // IITC matches the behaviour by default, but it makes sense to reduce the detail level sooner

    // at the largest scale zooms - move back two levels
    if (mapZoom <= 7) {
      return Math.max(mapZoom-2,0);
    }

    // intermediate zoom levels - move back one
    if (mapZoom <= 11) {
      return Math.max(mapZoom-1,0);
    }

    // otherwise revert to default behaviour
    return origGetPortalDataZoom();
  }


};

var setup =  window.plugin.showLessPortals.setup;

// PLUGIN END //////////////////////////////////////////////////////////


setup.info = plugin_info; //add the script info data to the function as a property
if(!window.bootPlugins) window.bootPlugins = [];
window.bootPlugins.push(setup);
// if IITC has already booted, immediately run the 'setup' function
if(window.iitcLoaded && typeof setup === 'function') setup();
} // wrapper end
// inject code into site context
var script = document.createElement('script');
var info = {};
if (typeof GM_info !== 'undefined' && GM_info && GM_info.script) info.script = { version: GM_info.script.version, name: GM_info.script.name, description: GM_info.script.description };
script.appendChild(document.createTextNode('('+ wrapper +')('+JSON.stringify(info)+');'));
(document.body || document.head || document.documentElement).appendChild(script);


